@@ -78,12 +78,12 @@ def plot_controls(
     -----
     As an example, the following are valid (and equivalent) ``control`` inputs ::
 
-        controls={
+        controls = {
             "Clock": {"durations": [1.0, 1.0, 2.0], "values": [-0.5, 0.5, -1.5]},
             "Microwave": {"durations": [0.5, 1.0], "values": [0.5 + 1.5j, 0.2 - 0.3j]},
         }
 
-        controls={
+        controls = {
             "Clock": [
                 {"duration": 1.0, "value": -0.5},
                 {"duration": 1.0, "value": 0.5},
@@ -94,6 +94,55 @@ def plot_controls(
                 {"duration": 1.0, "value": 0.2 - 0.3j},
             ],
         }
+
+    Examples
+    --------
+    Plot a linear ramp and a Gaussian pulse. ::
+
+        import numpy as np
+        from qctrl import Qctrl
+        from qctrlvisualizer import plot_controls
+
+        qctrl = Qctrl()
+
+        duration = 10e-6  # s
+        time_step = 0.01e-6  # s
+
+        amplitude = 2 * np.pi * 10e6  # Hz
+        drag_gaussian = 0.2
+
+        linear_ramp = qctrl.signals.linear_ramp(duration=duration, end_value=amplitude / 2)
+        gaussian_pulse = qctrl.signals.gaussian_pulse(
+            duration=duration, amplitude=amplitude, drag=drag_gaussian
+        )
+
+        controls = {
+            "Linear ramp": {
+                "durations": np.full(int(duration / time_step), time_step),
+                "values": linear_ramp.export_with_time_step(time_step),
+            },
+            "Gaussian": {
+                "durations": np.full(int(duration / time_step), time_step),
+                "values": gaussian_pulse.export_with_time_step(time_step),
+            },
+        }
+
+        plot_controls(controls, polar=False)
+
+
+    .. plot::
+
+        import json
+        import matplotlib.pyplot as plt
+        import numpy as np
+        from qctrlcommons.serializers import decode
+        from qctrlvisualizer import plot_controls
+
+        with open("../docs/plot_data/controls/plot_controls.json") as file:
+            controls = decode(json.load(file))
+
+        plot_controls(controls, polar=False)
+        plt.tight_layout()
     """
 
     boulder_opal_advice = (
@@ -422,11 +471,13 @@ def plot_sequences(sequences: dict, *, figure: plt.Figure):
         A matplotlib Figure in which to place the plots.
         If passed, its dimensions and axes will be overridden.
 
-    Notes
-    -----
-    As an example, the following is valid ``sequences`` input ::
+    Examples
+    --------
+    Plot a sequence of :math:`X`gates and a sequence of :math:`X` and :math:`Y` gates. ::
 
-        sequences={
+        from qctrlvisualizer import plot_sequences
+
+        sequences = {
             "X": [
                 {"offset": 0.0, "rotation": 0.1},
                 {"offset": 0.5, "rotation": 0.3},
@@ -439,6 +490,31 @@ def plot_sequences(sequences: dict, *, figure: plt.Figure):
                 {"offset": 2.0, "rotation": 0.2 - 0.3j},
             ],
         }
+
+        plot_sequences(sequences=sequences)
+
+
+    .. plot::
+
+        import matplotlib.pyplot as plt
+        from qctrlvisualizer import plot_sequences
+
+        sequences = {
+            "X": [
+                {"offset": 0.0, "rotation": 0.1},
+                {"offset": 0.5, "rotation": 0.3},
+                {"offset": 1.5, "rotation": 0.2},
+                {"offset": 2.0, "rotation": 0.4},
+            ],
+            "XY": [
+                {"offset": 0.0, "rotation": 0.5 + 0.5j},
+                {"offset": 1.0, "rotation": 0.3},
+                {"offset": 2.0, "rotation": 0.2 - 0.3j},
+            ],
+        }
+
+        plot_sequences(sequences)
+        plt.tight_layout()
     """
 
     check_argument(
