@@ -22,6 +22,7 @@ from typing import Any
 
 from cycler import cycler
 from matplotlib import rcParams
+from matplotlib.colors import LinearSegmentedColormap
 from matplotlib.pyplot import isinteractive
 from matplotlib.style import context
 
@@ -45,6 +46,13 @@ QCTRL_STYLE_COLORS = [
 ]
 
 
+QCTRL_SEQUENTIAL_COLORMAP = LinearSegmentedColormap.from_list(
+    "QCTRL_SEQUENTIAL_COLORMAP",
+    ["#EDE0FE", "#B482FA", "#680CE9", "#440087", "#1E0033"],
+    N=200,
+)
+
+
 def get_qctrl_style() -> dict[str, Any]:
     """
     Return a dictionary representing the Q-CTRL styling in Matplotlib format.
