@@ -166,3 +166,19 @@ def figure_as_kwarg_only(func):
     new_func.__annotations__["figure"] = Optional[plt.Figure]
 
     return new_func
+
+
+def safe_less_than(array, bound):
+    """
+    Returns False if any of the elements of array are less than bound (within rounding error).
+    Returns True otherwise.
+    """
+    return np.any((1 - np.isclose(array, bound)) * (array < bound))
+
+
+def safe_greater_than(array, bound):
+    """
+    Returns False if any of the elements of array are greater than bound (within rounding error).
+    Returns True otherwise.
+    """
+    return np.any((1 - np.isclose(array, bound)) * (array > bound))
