@@ -42,7 +42,7 @@ def plot_wigner_function(
     *,
     figure: plt.Figure,
 ):
-    """
+    r"""
     Create a contour plot of the specified Wigner function.
 
     Parameters
@@ -62,6 +62,54 @@ def plot_wigner_function(
     figure : matplotlib.figure.Figure, optional
         A matplotlib Figure in which to place the plots.
         If passed, its dimensions and axes will be overridden.
+
+    Examples
+    --------
+    Plot the Wigner function associated to state
+    :math:`(|0 \rangle + |5 \rangle) / \sqrt{2}`. ::
+
+        import numpy as np
+        from qctrl import Qctrl
+        from qctrlvisualizer import plot_wigner_function
+
+        qctrl = Qctrl()
+
+        position = np.linspace(-5, 5, 100)
+        momentum = np.linspace(-5, 5, 100)
+
+        graph = qctrl.create_graph()
+
+        state = (graph.fock_state(10, 0) + graph.fock_state(10, 5)) / np.sqrt(2)
+        density_matrix = graph.outer_product(state, state)
+
+        wigner_transform = graph.wigner_transform(
+            density_matrix, position, momentum, name="wigner_transform"
+        )
+
+        wigner_function = qctrl.functions.calculate_graph(
+            graph=graph, output_node_names=["wigner_transform"]
+        ).output["wigner_transform"]["value"]
+
+        plot_wigner_function(wigner_function, position, momentum)
+
+
+    .. plot::
+
+        import json
+        import matplotlib.pyplot as plt
+        import numpy as np
+        from qctrlcommons.serializers import decode
+        from qctrlvisualizer import plot_wigner_function
+
+        position = np.linspace(-5, 5, 100)
+        momentum = np.linspace(-5, 5, 100)
+
+        with open("../docs/plot_data/wigner_function/plot_wigner_function.json") as file:
+            wigner_function = decode(json.load(file))
+
+        plot_wigner_function(wigner_function, position, momentum)
+        plt.tight_layout()
+        plt.show()
     """
     check_argument(
         isinstance(wigner_function, np.ndarray) and wigner_function.ndim == 2,
